<?php
/**
 * Gossip functions and definitions.
 *
 * @link https://codex.wordpress.org/Functions_File_Explained
 *
 * @package gossip
 */

if ( ! function_exists( 'gossip_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function gossip_setup() {
		/**
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on gossip, use a find and replace
		 * to change 'gossip' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'gossip', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/**
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Menu', 'gossip' ),
			)
		);

		/**
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/**
		 * Enable support for Editor Style.
		 */
		function gossip_add_editor_styles() {

			add_editor_style( '/css/gossip-editor-style.css' );
		}
		add_action( 'after_setup_theme', 'gossip_add_editor_styles' );

		/**
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/**
		 * Enable support for Post Formats.
		 * See https://developer.wordpress.org/themes/functionality/post-formats/
		 */
		add_theme_support(
			'post-formats',
			array(
				'aside',
				'gallery',
				'image',
				'video',
				'audio',
				'quote',
				'link',
			)
		);

		/**
		 * Woocommerce Support
		 */
		add_theme_support( 'woocommerce' );

		/**
		 * Set up the WordPress core custom background feature.
		 */
		add_theme_support(
			'custom-background',
			apply_filters(
				'gossip_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'transport'     => 'refresh',
				)
			)
		);

		/**
		 * Add support for Block Styles.
		 */
		add_theme_support( 'wp-block-styles' );

		/**
		 * Register block pattern
		 */
		add_theme_support( 'register_block_pattern' );

		/**
		 * Align wide theme support
		 */
		add_theme_support( 'align-wide' );

		/**
		 * Supporting custom line heights
		 */
		add_theme_support( 'custom-line-height' );

		/**
		 * Support custom units
		 */
		add_theme_support( 'custom-units', 'rem', 'em' );

		/**
		 * html5 support
		 */
		add_theme_support( 'html5', [
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'style',
			'script',
			'navigation-widgets',
		] );

		/**
		 * Responsive embedded content
		 */
		add_theme_support( 'responsive-embeds' );

		/**
		 * Spacing control
		 */
		add_theme_support( 'custom-spacing' );

		/**
		 * Add support for color palette
		 */
		add_theme_support( 'editor-color-palette', array(
			array(
				'name'  => esc_attr__( 'Heading Color', 'gossip' ),
				'slug'  => 'gossip-heading',
				'color' => 	'#777778',
			),
			array(
				'name'  => esc_attr__( 'Border Color', 'gossip' ),
				'slug'  => 'gossip-border',
				'color' => 	'#e5e5e5',
			),
			array(
				'name'  => esc_attr__( 'Primary Color', 'gossip' ),
				'slug'  => 'gossip-primary',
				'color' => 	'#4fb2d9',
			),
			array(
				'name'  => esc_attr__( 'Gray 99', 'gossip' ),
				'slug'  => 'gossip-99-gray',
				'color' => 	'#999999',
			),
			array(
				'name'  => esc_attr__( 'Gray 66', 'gossip' ),
				'slug'  => 'gossip-66-gray',
				'color' => 	'#666666',
			),
			array(
				'name'  => esc_attr__( 'Gray 33', 'gossip' ),
				'slug'  => 'gossip-dark-33',
				'color' => 	'#333333',
			),
			array(
				'name'  => esc_attr__( 'Form Text', 'gossip' ),
				'slug'  => 'gossip-form-text',
				'color' => 	'#a7a7a7',
			),
			array(
				'name'  => esc_attr__( 'Form Background', 'gossip' ),
				'slug'  => 'gossip-form-bg',
				'color' => 	'#f9fafa',
			),
			array(
				'name'  => esc_attr__( 'Light Gray', 'gossip' ),
				'slug'  => 'gossip-light-gray',
				'color' => 	'#f5f5f5',
			),
			array(
				'name'  => esc_attr__( 'Light Gray Background', 'gossip' ),
				'slug'  => 'gossip-light-gray-bg',
				'color' => 	'#f5f5f5',
			),
		) );

	}
endif; // gossip_setup.
add_action( 'after_setup_theme', 'gossip_setup' );


/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function gossip_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'gossip_content_width', 640 );
}
add_action( 'after_setup_theme', 'gossip_content_width', 0 );


/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function gossip_widgets_init() {
	register_sidebar(
		array(
			'name'          => esc_html__( 'Sidebar Widget', 'gossip' ),
			'id'            => 'sidebar-1',
			'description'   => '',
			'before_widget' => '<div class="gossip-sidebar-container">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2>',
			'after_title'   => '</h2>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer Widget', 'gossip' ),
			'id'            => 'sidebar-2',
			'description'   => '',
			'before_widget' => '<div class="col-lg-3 col-md-3 col-sm-6 col-xs-12">',
			'after_widget'  => '</div>',
			'before_title'  => '<h2>',
			'after_title'   => '</h2>',
		)
	);
}
add_action( 'widgets_init', 'gossip_widgets_init' );


/**
 * Enqueue scripts and styles.
 */
function gossip_scripts() {

	/**
	* Enqueue styles
	*/

	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.css', '', '5.0.0' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/assets/css/font-awesome.css', '', '4.5.0' );
	wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Lato:400,300italic,300,400italic,700,700italic|Lustria&subset=latin,latin-ext', '', '1.0.0' );
	wp_enqueue_style( 'gossip-style', get_template_directory_uri() . '/assets/css/style.css', '', '1.0.0' );
	wp_enqueue_style( 'animate', get_template_directory_uri() . '/assets/css/animate.css', '', '3.4.0' );

	/**
	* Enqueue scripts
	*/

	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/assets/js/bootstrap.js', array( 'jquery' ), '5.0.0', true );
	wp_enqueue_script( 'gossip-custom', get_template_directory_uri() . '/assets/js/custom.js', array( 'jquery' ), '1.0.0', true );
	//wp_enqueue_script( 'mtree', get_template_directory_uri() . '/assets/js/mtree.js', array( 'jquery' ), '1.0.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'gossip_scripts' );

/**
 * Theme Customizer Option
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Implement the Custom Menu feature.
 */
require get_template_directory() . '/inc/custom-menu.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
